labeler_routes

Function labeler_routes 

pub fn labeler_routes(label_service: Arc<LabelService>) -> Router<AppState>
Build the labeler router with the label query endpoint.

Registers:

  • GET /xrpc/com.atproto.label.queryLabels

The returned router must be merged into the application router. The label_service is injected via an Axum [Extension] layer so that handlers can access it without polluting AppState.